==> jena-3.13.1-source-release.zip: jena-3.13.1/jena-arq/src/test/java/org/apache/jena/sparql/util/TestIntersectionDatasetGraph.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.util;

import static org.apache.jena.sparql.sse.SSE.parseGraph;

import org.apache.jena.graph.*;
import org.apache.jena.sparql.core.DatasetGraph;
import org.apache.jena.sparql.core.DatasetGraphFactory;
import org.junit.Test;

public class TestIntersectionDatasetGraph extends TestDyadicDatasetGraph {

    @Override
    public IntersectionDatasetGraph testInstance(DatasetGraph left, DatasetGraph right, Context c) {
        return new IntersectionDatasetGraph(left, right, c);
    }

    @Test
    public void testIntersection() {
        final Graph g1 = parseGraph("(graph (triple <s1> <p1> <o1> ))");
        final DatasetGraph dsg1 = DatasetGraphFactory.create(g1);
        final Node graphName1 = NodeFactory.createBlankNode();
        dsg1.addGraph(graphName1, g1);
        final Graph g2 = parseGraph("(graph (triple <s2> <p2> <o2> ))");
        final DatasetGraph dsg2 = DatasetGraphFactory.create(g2);
        final Node graphName2 = NodeFactory.createBlankNode();
        dsg2.addGraph(graphName2, g2);
        final Node graphName3 = NodeFactory.createBlankNode();
        dsg1.addGraph(graphName3, g1);
        dsg2.addGraph(graphName3, g1);
        DatasetGraph dsg = testInstance(dsg1, dsg2, Context.emptyContext);
        assertEquals(1, dsg.size());
        assertTrue(dsg.getDefaultGraph().isEmpty());
        assertTrue(dsg.getGraph(graphName1).isEmpty());
        assertTrue(dsg.getGraph(graphName2).isEmpty());
        assertTrue(g1.isIsomorphicWith(dsg.getGraph(graphName3)));
    }
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/test/java/org/apache/jena/sparql/util/TestIntersectionDatasetGraph.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.util;

import static org.apache.jena.sparql.sse.SSE.parseGraph;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

import org.apache.jena.graph.Graph;
import org.apache.jena.graph.Node;
import org.apache.jena.graph.NodeFactory;
import org.apache.jena.sparql.core.DatasetGraph;
import org.apache.jena.sparql.core.DatasetGraphFactory;

public class TestIntersectionDatasetGraph extends AbstractTestDyadicDatasetGraph {

    @Override
    public IntersectionDatasetGraph testInstance(DatasetGraph left, DatasetGraph right, Context c) {
        return new IntersectionDatasetGraph(left, right, c);
    }

    @Test
    public void testIntersection() {
        final Graph g1 = parseGraph("(graph (triple <s1> <p1> <o1> ))");
        final DatasetGraph dsg1 = DatasetGraphFactory.create(g1);
        final Node graphName1 = NodeFactory.createBlankNode();
        dsg1.addGraph(graphName1, g1);
        final Graph g2 = parseGraph("(graph (triple <s2> <p2> <o2> ))");
        final DatasetGraph dsg2 = DatasetGraphFactory.create(g2);
        final Node graphName2 = NodeFactory.createBlankNode();
        dsg2.addGraph(graphName2, g2);
        final Node graphName3 = NodeFactory.createBlankNode();
        dsg1.addGraph(graphName3, g1);
        dsg2.addGraph(graphName3, g1);
        DatasetGraph dsg = testInstance(dsg1, dsg2, Context.emptyContext());
        assertEquals(1, dsg.size());
        assertTrue(dsg.getDefaultGraph().isEmpty());
        assertTrue(dsg.getGraph(graphName1).isEmpty());
        assertTrue(dsg.getGraph(graphName2).isEmpty());
        assertTrue(g1.isIsomorphicWith(dsg.getGraph(graphName3)));
    }
}
